@@ -1,4 +1,4 @@
-# copyright 2015 LOGILAB S.A. (Paris, FRANCE), all rights reserved.
+# copyright 2015-2021 LOGILAB S.A. (Paris, FRANCE), all rights reserved.
 # contact http://www.logilab.fr -- mailto:contact@logilab.fr
 #
 # This program is free software: you can redistribute it and/or modify it under
@@ -96,7 +96,7 @@ def add_relations_button(req, entity, msg, *relations_info, **extraurlparams):
     """Return an HTML dropdown button to add relations with `entity` as object"""
     links = [relation_link(req, entity, relation_info, **extraurlparams)
              for relation_info in relations_info]
-    links = [l for l in links if l]
+    links = [link for link in links if link]
     if links:
         # No links if user cannot add any relation.
         return dropdown_button(req._(msg), links)
