@@ -1,4 +1,4 @@
-# copyright 2015 LOGILAB S.A. (Paris, FRANCE), all rights reserved.
+# copyright 2015-2021 LOGILAB S.A. (Paris, FRANCE), all rights reserved.
 # contact http://www.logilab.fr -- mailto:contact@logilab.fr
 #
 # This program is free software: you can redistribute it and/or modify it under
@@ -823,7 +823,7 @@ class AuthorityRecordGraphView(EntityView):
         for child_rel in entity.reverse_hierarchical_parent:
             for child in child_rel.hierarchical_child:
                 nprops = _node(child)
-                hiera_list += u'<li></li>'.format(nprops['title'])
+                hiera_list += u'<li>{}</li>'.format(nprops['title'])
         hiera_list += tags_closure
         self.w(hiera_list)
         domid = make_uid()
