@@ -1,5 +1,5 @@
 # coding: utf-8
-# copyright 2015 LOGILAB S.A. (Paris, FRANCE), all rights reserved.
+# copyright 2015-2021 LOGILAB S.A. (Paris, FRANCE), all rights reserved.
 # contact http://www.logilab.fr -- mailto:contact@logilab.fr
 #
 # This program is free software: you can redistribute it and/or modify it under
@@ -187,7 +187,7 @@ class FuncViewsTC(CubicWebTC):
             agent = testutils.authority_record(cnx, u'jim')
             for ark, expected_filename in (
                 (u"", "EAC_{0}.xml".format(agent.eid)),
-                (u"ZZZ/4242", "EAC_ZZZ-4242.xml".format(agent.eid)),
+                (u"ZZZ/4242", "EAC_ZZZ-4242.xml"),
             ):
                 agent.cw_set(ark=ark)
                 view = self.vreg['views'].select('eac.export', req, agent.as_rset())
